@@ -1,21 +1,8 @@
-/***********************************************************************
+/*
+ * SPDX-FileCopyrightText: 2014-2022 Megan Conkle <megan.conkle@kdemail.net>
  *
- * Copyright (C) 2014-2022 wereturtle
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+ * SPDX-License-Identifier: GPL-3.0-or-later
+ */
 
 #include <QProcess>
 #include <QString>
@@ -32,22 +19,27 @@ namespace ghostwriter
 Exporter::Exporter(const QString &name)
     : m_smartTypographyEnabled(false), 
       m_mathSupported(false),
-      m_name(name)
-{
-    ;
-}
+      m_userOptionsSupported(false),
+      m_name(name){}
 
-Exporter::~Exporter()
-{
-    ;
-}
+Exporter::~Exporter() = default;
 
 QString Exporter::name() const
 {
     return m_name;
 }
 
-const QList<const ExportFormat *> Exporter::supportedFormats() const
+QString Exporter::options() const
+{
+    return m_options;
+}
+
+void Exporter::setOptions(const QString &options)
+{
+    m_options = options;
+}
+
+QList<const ExportFormat *> Exporter::supportedFormats() const
 {
     return m_supportedFormats;
 }
@@ -67,6 +59,11 @@ bool Exporter::supportsMath() const
     return m_mathSupported;
 }
 
+bool Exporter::supportsUserOptions() const {
+    return m_userOptionsSupported;
+}
+
+
 void Exporter::exportToHtml(const QString &text, QString &html)
 {
     Q_UNUSED(text)
